/***************************************************************************
	file:			lcd_config.h
	product:	API-003
	descr:		Diese API ermoeglicht eine Ausgabe auf einem alphanumerischen LCD 
						mit einem HD44780, oder einem kompatiblen Displaycontroller. 
						Das LCD soll ueber einen 4-bit Datenbus mit dem Mikrocontroller 
						verbunden werden.
	
	date: 		10.2013 - first release

	version 	1.0
	compiler:	Keil Cx51 V9.05

	mc:				AT89C5131A
	crystal:	12MHz, 24MHz

	author: 	Viktor Schabelski info@approbe.de
	licence:	Creative Commons Lizenz
                http://www.stack2Learn.de/cc.html

**************************************************/


#ifndef _LCD_CONFIG_H_
	#define _LCD_CONFIG_H_

/*-----------------------------------------------------------------------------
	includes
---------------------------------------------------*/
#include <at89c5131.h>



/*-----------------------------------------------------------------------------
	keil editor wizard
---------------------------------------------------*/
//<<< Use Configuration Wizard in Context Menu >>>
// <h> Allgemeine LCD Einstellungen
// <o> LCD an Port
//					<0x80=> Port 0
//					<0x90=> Port 1
//					<0xA0=> Port 2
//					<0xB0=> Port 3
sfr LCD_PORT = 0xA0;			// 0xA0 Port 2 - default

sbit LCD_DB4 	=			LCD_PORT^0;		// Portpin P2.0 - default 
sbit LCD_DB5 	=			LCD_PORT^1;		// Portpin P2.1 - default
sbit LCD_DB6 	=			LCD_PORT^2;		// Portpin P2.2 - default
sbit LCD_DB7 	=			LCD_PORT^3;		// Portpin P2.3 - default
sbit LCD_EN 	=			LCD_PORT^4;		// Portpin P2.4 - default
sbit LCD_RW 	=			LCD_PORT^5;		// Portpin P2.5 - default
sbit LCD_RS 	=			LCD_PORT^6;		// Portpin P2.6 - default

sbit LCD_BACK_LIGHT =	LCD_PORT^7;		// Portpin P2.7 - default


// <o> Anzahl der Zeilen
//					<1=> 1 Zeile
//					<2=> 2 Zeilen
//					<3=> 3 Zeilen
//					<4=> 4 Zeilen
#define LCD_LINE_SIZE					0x02	// 0x02 - default value

// <o> Anzahl der Zeichen pro Zeile <0 - 40>
#define LCD_COLUMN_SIZE				0x08		// 0x08 -  DIPS082 default value

// <o> Adresse Zeile 1
#define LCD_ADDRESS_LINE_1		0x00		// 0x00 - default value

// <o> Adresse Zeile 2
#define LCD_ADDRESS_LINE_2		0x40		// 0x40 - default value

// <o> Adresse Zeile 3
#define LCD_ADDRESS_LINE_3		0x14		// 0x14 - default value

// <o> Adresse Zeile 4
#define LCD_ADDRESS_LINE_4		0x54		// 0x54 - default value

// </h>

// <h> LCD Register
// <h>3. Entry Mode Set
// <o.0> Bit 0: S (shift)
//					<0=> AUS
//					<1=> EIN
// <i> Shift-Art des Displays
// <o.1> Bit 1: I/D
//					<0=> Decrement
//					<1=> Increment
// <i> Festlegung der Bewegungsart des Cursors (nach rechts oder links)
// <i> Decrement Modus: CG oder DD-RAM Adresszaehler werden bei jedem Schreib- oder Lesevorgang um eins erniedrigt.
// <i> Increment Modus: CG oder DD-RAM Adresszaehler werden bei jedem Schreib- oder Lesevorgang um eins erhoeht.
// </h>
unsigned char ENTRY_MODE_SET = 0x06;


// <h>4. Display ON/OFF Control
// <o.0> Bit 0: B (blink)
//					<0=> AUS
//					<1=> EIN
// <i> Cursor-Blinken EIN/AUS
// <i> B - Blinkmodus:
// <i> Das Zeichen an der aktuellen Cursorposition blinkt in 400 ms Intervallen.
// <o.1> Bit 1: C (cursor)
//					<0=> AUS
//					<1=> EIN
// <i> Cursor EIN/AUS
// <o.2> Bit 2: D (display)
//					<0=> AUS
//					<1=> EIN
// <i> EIN und AUS- Schalten des Displays, der Inhalt des Display-Speichers geht dabei nicht verloren.
//</h>
unsigned char DISPLAY_CONTROL = 0x0D;


// <h>5. Cursor/Display Shift
// <o.2> Bit 2: R/L
//						<0=> Links
//						<1=> Rechts
// <o.3> Bit 3: S/C
//						<0=> Cursor
//						<1=> Display
// <i> Bewegung des Cursors und Shift des Displays festlegen, ohne den Inhalt des Display-Speichers zu veraendern.
// <i> S/C = Cursor (0), R/L = Links (0) => Bewegt den Cursor um eine Stelle nach links.
// <i> S/C = Cursor (0), R/L = Rechts (1) => Bewegt den Cursor um eine Stelle nach rechts.
// <i> S/C = Display (1), R/L = Links (0) => Verschiebt den Displayinhalt sowie den Cursor um eine Stelle nach links.
// <i> S/C = Display (1), R/L = Rechts (1) => Verschiebt den Displayinhalt sowie den Cursor um eine Stelle nach rechts.
//</h>
unsigned char CURSOR_DISPLAY_SHIFT = 0x14;


// <h>6. Function set
// <i> Einstellungen der Betriebsart des gesamten Displays.
// <o.2> Bit 2: F (font)
// <i> EA DIPS082 = 5x7 dots
//						<0=> 5x7 dots
//						<1=> 5x10 dots
// <o.3> Bit 3: N (line number)
//						<0=> 1x Displayzeile
//						<1=> 2x Displayzeilen
// <o.4> Bit 4: DL (data length)
//						<0=> 4-bit Bus
//						<1=> 8-bit Bus
//</h>
unsigned char FUNCTION_SET = 0x28;

// </h>
// end of configuration section >>>







#endif